@@ -66,7 +66,9 @@ BIT_ARG_MUST_BE_ZERO_OR_ONE = "ERR The bit argument must be 1 or 0."
 XADD_ID_LOWER_THAN_LAST = "ERR The ID specified in XADD is equal or smaller than the target stream top item"
 XADD_INVALID_ID = 'ERR Invalid stream ID specified as stream command argument'
 XGROUP_BUSYGROUP = 'ERR BUSYGROUP Consumer Group name already exists'
-XGROUP_GROUP_NOT_FOUND_MSG = "NOGROUP No such consumer group '%s' for key name '%s'"
+XREADGROUP_KEY_OR_GROUP_NOT_FOUND_MSG = (
+    "NOGROUP No such key '{0}' or consumer group '{1}' in XREADGROUP with GROUP option")
+XGROUP_GROUP_NOT_FOUND_MSG = "NOGROUP No such consumer group '{0}' for key name '{1}'"
 XGROUP_KEY_NOT_FOUND_MSG = (
     "ERR The XGROUP subcommand requires the key to exist."
     " Note that for CREATE you may want to use the MKSTREAM option to create an empty stream automatically.")
@@ -74,3 +76,6 @@ FLAG_NO_SCRIPT = 's'  # Command not allowed in scripts
 FLAG_LEAVE_EMPTY_VAL = 'v'
 FLAG_TRANSACTION = 't'
 GEO_UNSUPPORTED_UNIT = 'unsupported unit provided. please use M, KM, FT, MI'
+LPOS_RANK_CAN_NOT_BE_ZERO = "RANK can't be zero: use 1 to start from the first match, 2 from the second ... " \
+                            "or use negative to start from the end of the list"
+NUMKEYS_GREATER_THAN_ZERO_MSG = 'numkeys should be greater than 0'
