@@ -1,8 +1,21 @@
 import functools
 
 from fakeredis import _msgs as msgs
+from fakeredis._command_args_parsing import extract_args
 from fakeredis._commands import (Key, command, Int, CommandItem, Timeout, fix_range)
-from fakeredis._helpers import (OK, SimpleError, SimpleString, casematch)
+from fakeredis._helpers import (OK, SimpleError, SimpleString, casematch, Database)
+
+
+def _list_pop_count(get_slice, key, count):
+    if not key:
+        return None
+    elif type(key.value) != list:
+        raise SimpleError(msgs.WRONGTYPE_MSG)
+    slc = get_slice(count)
+    ret = key.value[slc]
+    del key.value[slc]
+    key.updated()
+    return ret
 
 
 def _list_pop(get_slice, key, *args):
@@ -19,20 +32,15 @@ def _list_pop(get_slice, key, *args):
         count = Int.decode(args[0], msgs.INDEX_NEGATIVE_ERROR_MSG)
         if count < 0:
             raise SimpleError(msgs.INDEX_NEGATIVE_ERROR_MSG)
-    if not key:
-        return None
-    elif type(key.value) != list:
-        raise SimpleError(msgs.WRONGTYPE_MSG)
-    slc = get_slice(count)
-    ret = key.value[slc]
-    del key.value[slc]
-    key.updated()
-    if not args:
+    ret = _list_pop_count(get_slice, key, count)
+    if ret and not args:
         ret = ret[0]
     return ret
 
 
 class ListCommandsMixin:
+    _db: Database
+
     def _bpop_pass(self, keys, op, first_pass):
         for key in keys:
             item = CommandItem(key, self._db, item=self._db.get(key), default=[])
@@ -138,6 +146,47 @@ class ListCommandsMixin:
     def lpop(self, key, *args):
         return _list_pop(lambda count: slice(None, count), key, *args)
 
+    def _lmpop(self, keys, count, direction_left, first_pass):
+        if direction_left:
+            op = lambda count: slice(None, count)  # noqa:E731
+        else:
+            op = lambda count: slice(None, -count - 1, -1)  # noqa:E731
+
+        for key in keys:
+            item = CommandItem(key, self._db, item=self._db.get(key), default=[])
+            res = _list_pop_count(op, item, count)
+            if res:
+                return [key, res]
+        return None
+
+    @command(fixed=(Int,), repeat=(bytes,))
+    def lmpop(self, numkeys, *args):
+        if numkeys <= 0:
+            raise SimpleError(msgs.NUMKEYS_GREATER_THAN_ZERO_MSG)
+        if casematch(args[-2], b'count'):
+            count = Int.decode(args[-1])
+            args = args[:-2]
+        else:
+            count = 1
+        if len(args) != numkeys + 1 or (not casematch(args[-1], b'left') and not casematch(args[-1], b'right')):
+            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+
+        return self._lmpop(args[:-1], count, casematch(args[-1], b'left'), False)
+
+    @command(fixed=(Timeout, Int,), repeat=(bytes,))
+    def blmpop(self, timeout, numkeys, *args):
+        if numkeys <= 0:
+            raise SimpleError(msgs.NUMKEYS_GREATER_THAN_ZERO_MSG)
+        if casematch(args[-2], b'count'):
+            count = Int.decode(args[-1])
+            args = args[:-2]
+        else:
+            count = 1
+        if len(args) != numkeys + 1 or (not casematch(args[-1], b'left') and not casematch(args[-1], b'right')):
+            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+
+        return self._blocking(timeout, functools.partial(self._lmpop, args[:-1], count, casematch(args[-1], b'left')))
+
     @command((Key(list), bytes), (bytes,))
     def lpush(self, key, *values):
         for value in values:
@@ -224,3 +273,31 @@ class ListCommandsMixin:
         if not key:
             return 0
         return self.rpush(key, *values)
+
+    @command(fixed=(Key(list), bytes,), repeat=(bytes,))
+    def lpos(self, key, elem, *args):
+        (rank, count, maxlen), _ = extract_args(args, ('+rank', '+count', '+maxlen',))
+        if rank == 0:
+            raise SimpleError(msgs.LPOS_RANK_CAN_NOT_BE_ZERO)
+        rank = rank or 1
+        ind, direction = (0, 1) if rank > 0 else (len(key.value) - 1, -1)
+        rank = abs(rank)
+        parse_count = len(key.value) if count == 0 else (count or 1)
+        maxlen = maxlen or len(key.value)
+        res = []
+        comparisons = 0
+        while (0 <= ind <= len(key.value) - 1
+               and len(res) < parse_count
+               and comparisons < maxlen):
+            comparisons += 1
+            if key.value[ind] == elem:
+                if rank > 1:
+                    rank -= 1
+                else:
+                    res.append(ind)
+            ind += direction
+        if len(res) == 0 and count is None:
+            return None
+        if len(res) == 1 and count is None:
+            return res[0]
+        return res
