@@ -5,12 +5,12 @@ import itertools
 import math
 import random
 import sys
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Tuple
 
 from fakeredis import _msgs as msgs
 from fakeredis._command_args_parsing import extract_args
 from fakeredis._commands import (command, Key, Int, Float, CommandItem, Timeout, ScoreTest, StringTest, fix_range)
-from fakeredis._helpers import (SimpleError, casematch, null_terminate, )
+from fakeredis._helpers import (SimpleError, casematch, null_terminate, Database, )
 from fakeredis._zset import ZSet
 
 SORTED_SET_METHODS = {
@@ -24,34 +24,38 @@ SORTED_SET_METHODS = {
 
 
 class SortedSetCommandsMixin:
+    _db: Database
+    version: Tuple[int]
+
     # Sorted set commands
-    def _zpop(self, key, count, reverse):
+    def _zpop(self, key: CommandItem, count: int, reverse: bool, flatten_list: bool) -> List[bytes]:
         zset = key.value
         members = list(zset)
         if reverse:
             members.reverse()
         members = members[:count]
-        res = [(bytes(member), self._encodefloat(zset.get(member), True)) for member in members]
-        res = list(itertools.chain.from_iterable(res))
+        res = [[bytes(member), self._encodefloat(zset.get(member), True)] for member in members]
+        if flatten_list:
+            res = list(itertools.chain.from_iterable(res))
         for item in members:
             zset.discard(item)
         return res
 
-    def _bzpop(self, keys, reverse, first_pass):
+    def _bzpop(self, keys: List[CommandItem], reverse: bool, first_pass: bool) -> Optional[List[bytes]]:
         for key in keys:
             item = CommandItem(key, self._db, item=self._db.get(key), default=[])
-            temp_res = self._zpop(item, 1, reverse)
+            temp_res = self._zpop(item, 1, reverse, True)
             if temp_res:
                 return [key, temp_res[0], temp_res[1]]
         return None
 
     @command((Key(ZSet),), (Int,))
-    def zpopmin(self, key, count=1):
-        return self._zpop(key, count, False)
+    def zpopmin(self, key, count: int = 1):
+        return self._zpop(key, count, reverse=False, flatten_list=True)
 
     @command((Key(ZSet),), (Int,))
-    def zpopmax(self, key, count=1):
-        return self._zpop(key, count, True)
+    def zpopmax(self, key, count: int = 1):
+        return self._zpop(key, count, reverse=True, flatten_list=True)
 
     @command((bytes, bytes), (bytes,), flags=msgs.FLAG_NO_SCRIPT)
     def bzpopmin(self, *args):
@@ -66,7 +70,7 @@ class SortedSetCommandsMixin:
         return self._blocking(timeout, functools.partial(self._bzpop, keys, True))
 
     @staticmethod
-    def _limit_items(items, offset, count):
+    def _limit_items(items: List, offset: int, count: int):
         out = []
         for item in items:
             if offset:  # Note: not offset > 0, in order to match redis
@@ -304,7 +308,7 @@ class SortedSetCommandsMixin:
         return self.zrem(key, *[item[1] for item in items])
 
     @command((Key(ZSet), Int, Int))
-    def zremrangebyrank(self, key, start, stop):
+    def zremrangebyrank(self, key, start: int, stop: int):
         zset = key.value
         start, stop = fix_range(start, stop, len(zset))
         items = zset.islice_score(start, stop)
@@ -510,5 +514,41 @@ class SortedSetCommandsMixin:
             res = [t[0] for t in res]
         return res
 
+    def _zmpop(self, keys, count, reverse, first_pass):
+        for key in keys:
+            item = CommandItem(key, self._db, item=self._db.get(key), default=[])
+            res = self._zpop(item, count, reverse, flatten_list=False)
+            if res:
+                return [key, res]
+        return None
+
+    @command(fixed=(Int,), repeat=(bytes,))
+    def zmpop(self, numkeys: int, *args):
+        if numkeys == 0:
+            raise SimpleError(msgs.NUMKEYS_GREATER_THAN_ZERO_MSG)
+        if casematch(args[-2], b'count'):
+            count = Int.decode(args[-1])
+            args = args[:-2]
+        else:
+            count = 1
+        if len(args) != numkeys + 1 or (not casematch(args[-1], b'min') and not casematch(args[-1], b'max')):
+            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+
+        return self._zmpop(args[:-1], count, casematch(args[-1], b'max'), False)
+
+    @command(fixed=(Timeout, Int,), repeat=(bytes,))
+    def bzmpop(self, timeout, numkeys: int, *args):
+        if numkeys == 0:
+            raise SimpleError(msgs.NUMKEYS_GREATER_THAN_ZERO_MSG)
+        if casematch(args[-2], b'count'):
+            count = Int.decode(args[-1])
+            args = args[:-2]
+        else:
+            count = 1
+        if len(args) != numkeys + 1 or (not casematch(args[-1], b'min') and not casematch(args[-1], b'max')):
+            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+
+        return self._blocking(timeout, functools.partial(self._zmpop, args[:-1], count, casematch(args[-1], b'max')))
+
     def _encodefloat(self, value, humanfriendly):
         raise NotImplementedError  # Implemented in BaseFakeSocket
